import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["className", "size", "skeleton", "name", "src", "fallbackIcon", "style", "isLoading", "children"];
import { Children, isValidElement, cloneElement, useCallback, forwardRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import AtomSkeleton, { ATOM_SKELETON_VARIANTS, ATOM_SKELETON_ANIMATIONS } from '@s-ui/react-atom-skeleton';
import useConvertStringToHex from './useConvertStringToHex.js';
import { baseClassName, AVATAR_SIZES } from './settings.js';
import AvatarFallback from './AvatarFallback/index.js';
import AvatarBadge, { AVATAR_BADGE_STATUSES, AVATAR_BADGE_PLACEMENTS, AVATAR_BADGE_SIZES } from './AvatarBadge/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeAvatar = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var classNameProp = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? AVATAR_SIZES.MEDIUM : _ref$size,
      _ref$skeleton = _ref.skeleton,
      skeleton = _ref$skeleton === void 0 ? /*#__PURE__*/_jsx(AtomSkeleton, {
    width: "100%",
    height: "100%",
    variant: ATOM_SKELETON_VARIANTS.circle,
    animation: ATOM_SKELETON_ANIMATIONS.wave
  }) : _ref$skeleton,
      name = _ref.name,
      src = _ref.src,
      fallbackIcon = _ref.fallbackIcon,
      style = _ref.style,
      isLoading = _ref.isLoading,
      childrenProp = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var className = cx(baseClassName, baseClassName + "--" + size);
  var backgroundColor = useConvertStringToHex(name);
  var children = Children.toArray(childrenProp).filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child) {
    return /*#__PURE__*/cloneElement(child, {
      size: size
    });
  });
  var renderContent = useCallback(function () {
    if (isLoading) {
      return skeleton;
    }

    var fallback = /*#__PURE__*/_jsx(AvatarFallback, {
      name: name,
      size: size,
      icon: fallbackIcon
    });

    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [src ? /*#__PURE__*/_jsx(AtomImage, {
        src: src,
        alt: name,
        errorIcon: fallback
      }) : fallback, !isLoading && children]
    });
  }, [isLoading, skeleton, children, src, name, fallbackIcon, size]);
  return /*#__PURE__*/_jsx("span", _extends({
    style: _extends({}, !src && {
      backgroundColor: backgroundColor
    }, style),
    className: className
  }, others, {
    ref: forwardedRef,
    children: renderContent()
  }));
});
MoleculeAvatar.displayName = 'MoleculeAvatar';
MoleculeAvatar.Badge = AvatarBadge;
export { AVATAR_SIZES as MOLECULE_AVATAR_SIZES };
export { AVATAR_SIZES as moleculeAvatarSizes };
export { AVATAR_BADGE_STATUSES as MOLECULE_AVATAR_BADGE_STATUSES };
export { AVATAR_BADGE_STATUSES as moleculeAvatarBadgeStatuses };
export { AVATAR_BADGE_PLACEMENTS as MOLECULE_AVATAR_BADGE_PLACEMENTS };
export { AVATAR_BADGE_PLACEMENTS as moleculeAvatarBadgePlacements };
export { AVATAR_BADGE_SIZES as MOLECULE_AVATAR_BADGE_SIZES };
export { AVATAR_BADGE_SIZES as moleculeAvatarBadgeSizes };
export default MoleculeAvatar;